Running thumbor server — Thumbor 7.0.0a1 documentation

# Running thumbor server

Running thumbor server is as easy as typing “thumbor” (considering you went through the proper Installing procedures).

The Server application takes some parameters that will help you tailor the thumbor Server to your needs. If you want to find out what the thumbor Server arguments are, just type:

    thumbor --help

## -i or –ip

The address that Tornado will listen for incoming request. It defaults to 0.0.0.0 (listening on localhost and current IP).

## -p or –port

The port that Tornado will listen for incoming request. It defaults to 8888.

## -c or –conf

The full path for the configuration file for this server.

## -k or –keyfile

The full path for the file containing the security key to be used for this server.

## -l or –log-level

The log level to be used. Possible values are: debug, info, warning, error, critical or notset. More on that at http://docs.python.org/library/logging.html. It defaults to warning.

## -a or –app

Allows the user to specify the application class to be used. This is a very advanced usage of thumbor. This argument is specified like: “namespace1.namespace2.class_name” as in “myproj.thumbor_support.MyProjThumborApp”.

### Signing thumbor urls

To help users create signed URLs (mostly for debugging purposes, since we recommend using the Libraries), thumbor comes with an application called thumbor-url.

In order to use it, type `thumbor-url -h` and it will present all options available.